/*  2. This comment should be extracted. */
char *s = N_("Find Files...");
/*  4. This comment also should be extracted. */
char *s = N_("Locate documents and folders on this computer by name or content");
char *s = N_("Blue");
char *s = N_("Red");
char *s = N_("Green");
char *s = N_("Yellow");
